@@ -273,10 +273,10 @@ bool EnttecDMXUSBPro::extractSerial()
             uchar(reply[2]) == 0x04 && uchar(reply[3]) == 0x00 &&
             uchar(reply[8]) == 0xe7)
         {
-            m_proSerial.sprintf("%x%.2x%.2x%.2x", uchar(reply[7]),
-                                                  uchar(reply[6]),
-                                                  uchar(reply[5]),
-                                                  uchar(reply[4]));
+            m_proSerial = m_proSerial.asprintf("%x%.2x%.2x%.2x", uchar(reply[7]),
+                                                                 uchar(reply[6]),
+                                                                 uchar(reply[5]),
+                                                                 uchar(reply[4]));
             qDebug() << Q_FUNC_INFO << "Serial number OK: " << m_proSerial;
             return true;
         }
