@@ -139,7 +139,7 @@ QVariantList FixtureManager::universeInfo(quint32 id)
         {
             quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
             quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
-            int flags = m_monProps->fixtureFlags(fixtureID, headIndex, linkedIndex);
+            quint32 flags = m_monProps->fixtureFlags(fixtureID, headIndex, linkedIndex);
             if (flags & MonitorProperties::HiddenFlag)
                 continue;
 
@@ -885,6 +885,48 @@ QString FixtureManager::channelName(quint32 fxID, quint32 chIdx)
     return channel->name();
 }
 
+int FixtureManager::channelType(quint32 fxID, quint32 chIdx)
+{
+    Fixture *fixture = m_doc->fixture(fxID);
+    if (fixture == nullptr)
+        return QLCChannel::NoGroup;
+
+    const QLCChannel *channel = fixture->channel(chIdx);
+    if (channel == nullptr)
+        return QLCChannel::NoGroup;
+
+    if (channel->group() == QLCChannel::Intensity)
+        return channel->colour();
+    else
+        return channel->group();
+}
+
+qreal FixtureManager::channelDegrees(quint32 fxID, quint32 chIdx)
+{
+    Fixture *fixture = m_doc->fixture(fxID);
+    if (fixture == nullptr)
+        return 0;
+
+    const QLCChannel *channel = fixture->channel(chIdx);
+    if (channel == nullptr)
+        return 0;
+
+    if (channel->group() != QLCChannel::Pan &&
+        channel->group() != QLCChannel::Tilt)
+        return 0;
+
+    QRectF rect = fixture->degreesRange(0);
+
+    if (channel->group() == QLCChannel::Pan)
+    {
+        return (channel->controlByte() == QLCChannel::MSB) ? rect.width() : rect.width() / 255.0;
+    }
+    else
+    {
+        return (channel->controlByte() == QLCChannel::MSB) ? rect.height() : rect.height() / 255.0;
+    }
+}
+
 void FixtureManager::slotFixtureAdded(quint32 id, QVector3D pos)
 {
     if (m_doc->loadStatus() == Doc::Loading)
@@ -1478,16 +1520,6 @@ void FixtureManager::setColorValue(quint8 red, quint8 green, quint8 blue,
     emit colorChanged(QColor(red, green, blue), QColor(white, amber, uv));
 }
 
-void FixtureManager::setPanValue(int degrees)
-{
-    emit positionTypeValueChanged(QLCChannel::Pan, degrees);
-}
-
-void FixtureManager::setTiltValue(int degrees)
-{
-    emit positionTypeValueChanged(QLCChannel::Tilt, degrees);
-}
-
 void FixtureManager::setPresetValue(quint32 fixtureID, int chIndex, quint8 value)
 {
     qDebug() << "[FixtureManager] setPresetValue - fixture:" << fixtureID << ", channel:" << chIndex << "value:" << value;
@@ -1733,79 +1765,11 @@ void FixtureManager::resetCapabilities()
 
 QList<SceneValue> FixtureManager::getFixturePosition(quint32 fxID, int type, int degrees)
 {
-    QList<SceneValue> posList;
-    // cache a list of channels processed, to avoid duplicates
-    QList<quint32> chDone;
-
     Fixture *fixture = m_doc->fixture(fxID);
     if (fixture == nullptr || fixture->fixtureMode() == nullptr)
-        return posList;
+        return QList<SceneValue>();
 
-    QLCPhysical phy = fixture->fixtureMode()->physical();
-    float maxDegrees;
-    if (type == QLCChannel::Pan)
-    {
-        maxDegrees = phy.focusPanMax();
-        if (maxDegrees == 0) maxDegrees = 360;
-
-        for (int i = 0; i < fixture->heads(); i++)
-        {
-            quint32 panMSB = fixture->channelNumber(QLCChannel::Pan, QLCChannel::MSB, i);
-            if (panMSB == QLCChannel::invalid() || chDone.contains(panMSB))
-                continue;
-
-            float dmxValue = (float)(degrees * UCHAR_MAX) / maxDegrees;
-            posList.append(SceneValue(fixture->id(), panMSB, static_cast<uchar>(qFloor(dmxValue))));
-
-            qDebug() << "[getFixturePosition] Pan MSB:" << dmxValue;
-
-            quint32 panLSB = fixture->channelNumber(QLCChannel::Pan, QLCChannel::LSB, i);
-
-            if (panLSB != QLCChannel::invalid())
-            {
-                float lsbDegrees = (float)maxDegrees / (float)UCHAR_MAX;
-                float lsbValue = (float)((dmxValue - qFloor(dmxValue)) * UCHAR_MAX) / lsbDegrees;
-                posList.append(SceneValue(fixture->id(), panLSB, static_cast<uchar>(lsbValue)));
-
-                qDebug() << "[getFixturePosition] Pan LSB:" << lsbValue;
-            }
-
-            chDone.append(panMSB);
-        }
-    }
-    else if (type == QLCChannel::Tilt)
-    {
-        maxDegrees = phy.focusTiltMax();
-        if (maxDegrees == 0) maxDegrees = 270;
-
-        for (int i = 0; i < fixture->heads(); i++)
-        {
-            quint32 tiltMSB = fixture->channelNumber(QLCChannel::Tilt, QLCChannel::MSB, i);
-            if (tiltMSB == QLCChannel::invalid() || chDone.contains(tiltMSB))
-                continue;
-
-            float dmxValue = (float)(degrees * UCHAR_MAX) / maxDegrees;
-            posList.append(SceneValue(fixture->id(), tiltMSB, static_cast<uchar>(qFloor(dmxValue))));
-
-            qDebug() << "[getFixturePosition] Tilt MSB:" << dmxValue;
-
-            quint32 tiltLSB = fixture->channelNumber(QLCChannel::Tilt, QLCChannel::LSB, i);
-
-            if (tiltLSB != QLCChannel::invalid())
-            {
-                float lsbDegrees = (float)maxDegrees / (float)UCHAR_MAX;
-                float lsbValue = (float)((dmxValue - qFloor(dmxValue)) * UCHAR_MAX) / lsbDegrees;
-                posList.append(SceneValue(fixture->id(), tiltLSB, static_cast<uchar>(lsbValue)));
-
-                qDebug() << "[getFixturePosition] Tilt LSB:" << lsbValue;
-            }
-
-            chDone.append(tiltMSB);
-        }
-
-    }
-
-    return posList;
+    return fixture->positionToValues(type, degrees);
 }
 
 QVariantList FixtureManager::presetsChannels(QLCChannel::Group group)
@@ -1923,6 +1887,34 @@ QVariantList FixtureManager::presetCapabilities(quint32 fixtureID, int chIndex)
     return var;
 }
 
+QVariantList FixtureManager::presetChannel(quint32 fixtureID, int chIndex)
+{
+    QVariantList prList;
+
+    Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return prList;
+
+    const QLCFixtureDef *def = fixture->fixtureDef();
+    const QLCFixtureMode *mode = fixture->fixtureMode();
+
+    if (def == nullptr || mode == nullptr)
+        return prList;
+
+    const QLCChannel *ch = fixture->channel(chIndex);
+
+    if (ch == nullptr)
+        return prList;
+
+    QVariantMap prMap;
+    prMap.insert("name", ch->name());
+    prMap.insert("fixtureID", fixtureID);
+    prMap.insert("channelIdx", chIndex);
+    prList.append(prMap);
+
+    return prList;
+}
+
 int FixtureManager::colorsMask() const
 {
     return m_colorsMask;
