@@ -521,8 +521,7 @@ void ConsoleChannel::initCapabilityMenu(const QLCChannel* ch)
 
             for (int i = cap->min(); i <= cap->max(); i++)
             {
-                action = valueMenu->addAction(
-                             t.sprintf("%.3d", i));
+                action = valueMenu->addAction(t.asprintf("%.3d", i));
                 action->setData(i);
             }
 
