@@ -456,7 +456,7 @@ void FunctionWizard::updateWidgetsTree()
             frame->setIcon(KWidgetName, VCWidget::typeToIcon(VCWidget::FrameWidget));
             frame->setData(KWidgetName, Qt::UserRole, VCWidget::FrameWidget);
         }
-        frame->setData(KWidgetName, Qt::UserRole + 1, qVariantFromValue((void *)palette));
+        frame->setData(KWidgetName, Qt::UserRole + 1, QVariant::fromValue((void *)palette));
         frame->setFlags(frame->flags() | Qt::ItemIsUserCheckable | Qt::ItemIsTristate);
         frame->setCheckState(KWidgetName, Qt::Unchecked);
 
@@ -482,7 +482,7 @@ void FunctionWizard::updateWidgetsTree()
             item->setIcon(KWidgetName, VCWidget::typeToIcon(VCWidget::ButtonWidget));
             item->setCheckState(KWidgetName, Qt::Unchecked);
             item->setData(KWidgetName, Qt::UserRole, VCWidget::ButtonWidget);
-            item->setData(KWidgetName, Qt::UserRole + 1, qVariantFromValue((void *)scene));
+            item->setData(KWidgetName, Qt::UserRole + 1, QVariant::fromValue((void *)scene));
 
         }
         foreach(Chaser *chaser, palette->chasers())
@@ -493,7 +493,7 @@ void FunctionWizard::updateWidgetsTree()
             item->setIcon(KWidgetName, VCWidget::typeToIcon(VCWidget::CueListWidget));
             item->setCheckState(KWidgetName, Qt::Unchecked);
             item->setData(KWidgetName, Qt::UserRole, VCWidget::CueListWidget);
-            item->setData(KWidgetName, Qt::UserRole + 1, qVariantFromValue((void *)chaser));
+            item->setData(KWidgetName, Qt::UserRole + 1, QVariant::fromValue((void *)chaser));
         }
 
         foreach(RGBMatrix *matrix, palette->matrices())
@@ -508,7 +508,7 @@ void FunctionWizard::updateWidgetsTree()
             item->setIcon(KWidgetName, VCWidget::typeToIcon(VCWidget::ButtonWidget));
             item->setCheckState(KWidgetName, Qt::Unchecked);
             item->setData(KWidgetName, Qt::UserRole, VCWidget::ButtonWidget);
-            item->setData(KWidgetName, Qt::UserRole + 1, qVariantFromValue((void *)matrix));
+            item->setData(KWidgetName, Qt::UserRole + 1, QVariant::fromValue((void *)matrix));
         }
 
         if (palette->scenes().count() > 0)
@@ -527,7 +527,7 @@ void FunctionWizard::updateWidgetsTree()
             item->setCheckState(KWidgetName, Qt::Unchecked);
             item->setData(KWidgetName, Qt::UserRole, VCWidget::SliderWidget);
             Scene *firstScene = palette->scenes().at(0);
-            item->setData(KWidgetName, Qt::UserRole + 1, qVariantFromValue((void *)firstScene));
+            item->setData(KWidgetName, Qt::UserRole + 1, QVariant::fromValue((void *)firstScene));
         }
     }
 }
