@@ -1231,7 +1231,7 @@ void VCSlider::setTopLabelText(int value)
 
     if (valueDisplayStyle() == ExactValue)
     {
-        text.sprintf("%.3d", value);
+        m_topLabel->setText(text.asprintf("%.3d", value));
     }
     else
     {
@@ -1240,9 +1240,8 @@ void VCSlider::setTopLabelText(int value)
         if (m_slider)
             f = SCALE(float(value), float(m_slider->minimum()),
                       float(m_slider->maximum()), float(0), float(100));
-        text.sprintf("%.3d%%", static_cast<int> (f));
+        m_topLabel->setText(text.asprintf("%.3d%%", static_cast<int> (f)));
     }
-    m_topLabel->setText(text);
 
     emit valueChanged(text);
 }
@@ -1829,8 +1828,18 @@ VCSlider::LevelChannel::LevelChannel(quint32 fid, quint32 ch)
 
 VCSlider::LevelChannel::LevelChannel(const LevelChannel& lc)
 {
-    this->fixture = lc.fixture;
-    this->channel = lc.channel;
+    *this = lc;
+}
+
+VCSlider::LevelChannel &VCSlider::LevelChannel::operator=(const VCSlider::LevelChannel &lc)
+{
+    if (this != &lc)
+    {
+        this->fixture = lc.fixture;
+        this->channel = lc.channel;
+    }
+
+    return *this;
 }
 
 bool VCSlider::LevelChannel::operator==(const LevelChannel& lc) const
